==> ovirt-engine-sdk-java-4.1.3.tar.gz: ovirt-engine-sdk-java-4.1.3/target/generated-sources/org/ovirt/engine/sdk4/services/SchedulingPoliciesService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.SchedulingPolicyBuilder;
import org.ovirt.engine.sdk4.types.SchedulingPolicy;

public interface SchedulingPoliciesService extends Service {
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest policy(SchedulingPolicy policy);
        AddRequest policy(SchedulingPolicyBuilder policy);
    }
    
    public interface AddResponse extends Response {
        SchedulingPolicy policy();
    }
    
    AddRequest add();
    
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Indicates if the results should be filtered according to the permissions of the user.
         */
        ListRequest filter(Boolean filter);
        /**
         * Sets the maximum number of policies to return. If not specified all the policies are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of policies to return. If not specified all the policies are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of policies to return. If not specified all the policies are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    public interface ListResponse extends Response {
        List<SchedulingPolicy> policies();
    }
    
    ListRequest list();
    
    SchedulingPolicyService policyService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

==> ovirt-engine-sdk-java-4.1.4.tar.gz: ovirt-engine-sdk-java-4.1.4/target/generated-sources/org/ovirt/engine/sdk4/services/SchedulingPoliciesService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.SchedulingPolicyBuilder;
import org.ovirt.engine.sdk4.types.SchedulingPolicy;

/**
 * Manages the set of scheduling policies available in the system.
 */
public interface SchedulingPoliciesService extends Service {
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest policy(SchedulingPolicy policy);
        AddRequest policy(SchedulingPolicyBuilder policy);
    }
    
    public interface AddResponse extends Response {
        SchedulingPolicy policy();
    }
    
    AddRequest add();
    
    /**
     * Returns the list of scheduling policies available in the system.
     * 
     * The order of the returned list of scheduling policies isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Indicates if the results should be filtered according to the permissions of the user.
         */
        ListRequest filter(Boolean filter);
        /**
         * Sets the maximum number of policies to return. If not specified all the policies are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of policies to return. If not specified all the policies are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of policies to return. If not specified all the policies are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    /**
     * Returns the list of scheduling policies available in the system.
     * 
     * The order of the returned list of scheduling policies isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<SchedulingPolicy> policies();
    }
    
    /**
     * Returns the list of scheduling policies available in the system.
     * 
     * The order of the returned list of scheduling policies isn't guaranteed.
     */
    ListRequest list();
    
    SchedulingPolicyService policyService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}
